@@ -7,6 +7,7 @@
 
 #pragma once
 
+#include "kcmaccessibilityactivationgestures.h"
 #include "kcmaccessibilitybell.h"
 #include "kcmaccessibilitykeyboard.h"
 #include "kcmaccessibilitykeyboardfilters.h"
@@ -73,6 +74,8 @@ private:
     KeyboardFiltersSettings m_keyboardFiltersSettings;
     MouseSettings m_mouseSettings;
     ScreenReaderSettings m_screenReaderSettings;
+    ActivationGesturesSettings m_activationGesturesSettings;
+    KConfig m_kdeglobals;
 
     int xkb_opcode;
     unsigned int features;
@@ -81,7 +84,6 @@ private:
     QWidget *overlay;
 
     ca_context *m_caContext = nullptr;
-    QUrl m_currentPlayerSource;
 
     WId _activeWindow;
 
