@@ -4,8 +4,7 @@
     SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-#ifndef D_PTR_H
-#define D_PTR_H
+#pragma once
 
 #include <memory>
 
@@ -37,5 +36,3 @@ public:
 
 } // namespace utils
 } // namespace kamd
-
-#endif
