@@ -17,11 +17,32 @@
 #include "gamepad.h"
 #include "logging.h"
 
+// 100 ms while we have devices
+const int kShortPollTime = 100;
+// 2 seconds while we don't have any devices
+const int kLongPollTime = 2000;
+
+static bool initialized = false;
+
 DeviceModel::DeviceModel()
 {
-    auto timer = new QTimer(this);
-    connect(timer, &QTimer::timeout, this, &DeviceModel::poll);
-    timer->start(1);
+    m_timer = new QTimer(this);
+    connect(m_timer, &QTimer::timeout, this, &DeviceModel::poll);
+    // Only poll once per 2 seconds until we have a device
+    m_timer->start(kLongPollTime);
+
+    // Also call it once after we have initialized in case
+    // there are already controllers.
+    QTimer::singleShot(kShortPollTime, this, &DeviceModel::poll);
+}
+
+DeviceModel::~DeviceModel()
+{
+    if (initialized) {
+        qCDebug(KCM_GAMECONTROLLER) << "Calling SDL_Quit";
+        SDL_Quit();
+        initialized = false;
+    }
 }
 
 Gamepad *DeviceModel::device(int index) const
@@ -56,6 +77,12 @@ QVariant DeviceModel::data(const QModelIndex &index, int role) const
 
 void DeviceModel::poll()
 {
+    if (!initialized) {
+        qCDebug(KCM_GAMECONTROLLER) << "Calling SDL_Init";
+        SDL_Init(SDL_INIT_GAMECONTROLLER);
+        initialized = true;
+    }
+
     SDL_Event event{};
     while (SDL_PollEvent(&event)) {
         switch (event.type) {
@@ -96,6 +123,8 @@ void DeviceModel::addDevice(const int deviceIndex)
     m_devices.insert(id, new Gamepad(joystick, gamepad, this));
     endInsertRows();
 
+    // Now that we have a device poll every short poll time
+    m_timer->setInterval(kShortPollTime);
     Q_EMIT devicesChanged();
 }
 
@@ -113,6 +142,10 @@ void DeviceModel::removeDevice(const int deviceIndex)
     m_devices.remove(deviceIndex);
     endRemoveRows();
 
+    if (m_devices.count() == 0) {
+        // Go back to long timeout polling now that we don't have a device
+        m_timer->setInterval(kLongPollTime);
+    }
     Q_EMIT devicesChanged();
 }
 
