@@ -7,9 +7,13 @@
 #pragma once
 
 #include "inputbackend.h"
+#include "inputdevice.h"
+#include "x11_libinput_dummydevice.h"
 
 #include <QList>
 
+#include <memory>
+
 class X11LibinputBackend : public InputBackend
 {
     Q_OBJECT
@@ -20,16 +24,16 @@ public:
 
     void kcmInit() override;
 
-    bool applyConfig() override;
-    bool getConfig() override;
-    bool getDefaultConfig() override;
-    bool isChangedConfig() const override;
+    bool save() override;
+    bool load() override;
+    bool defaults() override;
+    bool isSaveNeeded() const override;
     QString errorString() const override;
     int deviceCount() const override;
-    bool isAnonymousDevice() const override;
-    QList<QObject *> getDevices() const override;
+    bool isAnonymousInputDevice() const override;
+    QList<InputDevice *> inputDevices() const override;
 
 private:
-    QObject *m_device;
-    QString m_errorString = QString();
+    std::unique_ptr<X11LibinputDummyDevice> m_device;
+    QString m_errorString;
 };
